"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const TextField_1 = require("./styles/TextField");
class ContentEditable extends React.Component {
    constructor() {
        super(...arguments);
        this.state = { editing: false };
        this.selectAll = () => {
            let sel, range;
            if (window.getSelection && document.createRange) {
                range = document.createRange();
                range.selectNodeContents(this.elem);
                sel = window.getSelection();
                sel.removeAllRanges();
                sel.addRange(range);
            }
        };
        this.handleKeyDown = (evt) => {
            //exit edit mode on escape key
            if (evt.key === 'Escape') {
                evt.preventDefault();
                this.elem.blur();
            }
        };
        this.finishEditing = () => {
            const newValue = this.elem && this.elem.innerHTML;
            this.setState({ editing: false });
            this.props.onChange(newValue);
        };
        this.startEditing = () => {
            const { disabled, selectOnFocus } = this.props;
            !disabled && this.setState({ editing: true }, () => selectOnFocus && this.selectAll());
        };
        this.content = () => {
            const { content, displayContent } = this.props;
            return this.state.editing ? content : displayContent ? displayContent : content;
        };
    }
    shouldComponentUpdate(nextProps, nextState) {
        return (nextProps.content !== this.props.content ||
            nextProps.disabled !== this.props.disabled ||
            nextState.editing !== this.state.editing);
    }
    componentDidMount() {
        if (this.props.autofocus) {
            this.elem.focus();
            this.startEditing();
        }
    }
    render() {
        const { disabled, onKeyPress } = this.props;
        return (React.createElement(TextField_1.StyledView, { suppressContentEditableWarning: true, innerRef: elem => (this.elem = elem), contentEditable: !disabled, placeholder: "click to edit", dangerouslySetInnerHTML: { __html: this.content() }, onFocus: this.startEditing, onClick: this.startEditing, onBlur: this.finishEditing, onKeyDown: this.handleKeyDown, onKeyPress: onKeyPress }));
    }
}
ContentEditable.defaultProps = {
    disabled: false,
    autofocus: false,
    selectOnFocus: false,
    onKeyDown: () => { },
    onKeyPress: () => { }
};
exports.default = ContentEditable;
//# sourceMappingURL=ContentEditable.js.map